package com.example.artfromjson_kotlin

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.View
import android.widget.*
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject


class MainActivity : AppCompatActivity() {

    //declare a global JSONarray -- the array of objects we will get from reading the JSON file

    //keep track of the selected painter and painting using an index
    var painterIndex = 0
    var paintingIndex = 0

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val spPainting = findViewById(R.id.spPainting) as Spinner
        val spPainter = findViewById(R.id.spArtist) as Spinner
        val tvBirth = findViewById(R.id.tvBirth) as TextView
        val tvDeath = findViewById(R.id.tvDeath) as TextView
        val tvCountry = findViewById(R.id.tvCountry) as TextView

        try {
            val input_stream = resources.openRawResource(R.raw.painting_data)
            val buffer = ByteArray(input_stream.available())
            while (input_stream.read(buffer) !== -1);

            val myText = String(buffer)
            //extract the main (top-level) JSON object from the file read above
            val myJSON_object = JSONObject(myText)

            //the main JSON object is/includes an array called painters
            //extract that array
             var myJSON_array = myJSON_object.getJSONArray("painters")

            //create a String array of artist first and last names -- used to populate spinner
            val artist_name = arrayOfNulls<String>(myJSON_array.length())
            for (i in 0 until myJSON_array.length()) {
                try {
                    //get an individual element of the JSON array
                    val aJSON_element = myJSON_array.getJSONObject(i)
                    //get the individual properties of the JSON element
                    val first_name = aJSON_element.getString("firstName")
                    val last_name = aJSON_element.getString("lastName")
                    //make the artist full name
                    artist_name[i] = "$first_name. $last_name"
                } catch (e: JSONException) {
                    Toast.makeText(baseContext, "Dude, you have to know what the JSON looks like to parse it",
                        Toast.LENGTH_SHORT).show()
                    e.printStackTrace()
                }
                //end try-catch of JSON decoding file and making artist array
            } //end loop over myJSON_array

            //associate the artist full name with the spinner
            val aaPainter = ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, artist_name)
            aaPainter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item) // The drop down view
            spPainter.adapter = aaPainter

            //when user chooses and artist
            spPainter.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
                override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {

                    painterIndex = i // remember what the user chooses

                    val tvUserItem = view as TextView
                    Toast.makeText(applicationContext, "You chose " + tvUserItem.text.toString(), Toast.LENGTH_SHORT).show()
                    try {
                        tvBirth.text = "  " + myJSON_array.getJSONObject(i).getString("birthDate")
                        tvDeath.text = "  to          " + myJSON_array.getJSONObject(i).getString("deathDate")
                        tvCountry.text = "  " + myJSON_array.getJSONObject(i).getString("countryName")

                        val artistPaintings = myJSON_array.getJSONObject(i).getJSONArray("paintings")

                        // the file has a different number of paintings for various artists
                        // so use list instead of array
                        val painting_titles = ArrayList<String>()
                        for (k in 0 until artistPaintings.length()) {
                            try {
                                val aPainting = artistPaintings.getJSONObject(k)
                                painting_titles.add(aPainting.getString("title"))
                            } catch (e: JSONException) {
                                e.printStackTrace()
                            }
                        }//end loop over paintings

                        spPainting.adapter = null  //clears spinner of any old paintings from previous artist

                        val aaPainting = ArrayAdapter(baseContext, android.R.layout.simple_spinner_item, painting_titles)
                        aaPainting.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item) // The drop down view
                        spPainting.adapter = aaPainting

                        //when the user chose a painting of the selected artist
                        spPainting.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
                            override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {
                                val tvUserChoice = view as TextView

                                paintingIndex = i  //remember what the user chooses

                                try {
                                    //get the selected artist's selected painting
                                    var paintingFilename =
                                        myJSON_array.getJSONObject(painterIndex).getJSONArray("paintings")
                                            .getJSONObject(paintingIndex).getString("filename")
                                    Toast.makeText(applicationContext, "You chose $paintingFilename", Toast.LENGTH_SHORT).show()

                                    val ivPainting = findViewById(R.id.ivPainting) as ImageView
                                    //eliminate file extension
                                    paintingFilename = paintingFilename.substring(0, paintingFilename.lastIndexOf('.'))
                                    //replace any dash with underscore
                                    paintingFilename = paintingFilename.replace("-", "_")
                                    //put into all lower case
                                    paintingFilename = paintingFilename.toLowerCase()
                                    val iv_id = resources.getIdentifier(paintingFilename, "drawable", packageName)
                                    ivPainting.setImageResource(iv_id)
                                } catch (e: JSONException) {
                                    e.printStackTrace()
                                }
                                //end of try-catch for painting JSON decode
                            }//end of onItemSelected of Painting spinner

                            override fun onNothingSelected(adapterView: AdapterView<*>) {}
                        }// end of setOnItemSelectedListener

                    } catch (e: Exception) {
                        e.printStackTrace()
                    }
                } //end onItemSelected

                override fun onNothingSelected(adapterView: AdapterView<*>) {}
            }// end of Painter setOnItemSelectedListener

        } catch (e: Exception) {
            Toast.makeText(baseContext, "Problem with file", Toast.LENGTH_LONG).show()
            e.printStackTrace()
        }
        //end try-catch of reading file

    }//end onCreate
}//end MainActivity